@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 '''
 {{module_name}} state module
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -14,14 +13,10 @@
 
 '''
 
-# Import Python libs
-from __future__ import absolute_import, unicode_literals, print_function
 import logging
 
-# Import salt libs
 import salt.utils.compat
 
-# Import third party libs
 try:
     #  Import libs...
     {% if depending_libraries %}
@@ -51,7 +46,7 @@ def __virtual__():
 
 def __init__(opts):
     #  Put logic here to instantiate underlying jobs/connections
-    salt.utils.compat.pack_dunder(__name__)
+    pass
 
 
 def present(name):
