@@ -4,14 +4,13 @@
 
 import os
 import tempfile
-import time
 
+import pytest
 import salt.config
 import salt.loader
 import salt.states.saltmod as saltmod
 import salt.utils.event
 import salt.utils.jid
-from tests.support.helpers import slowTest
 from tests.support.mixins import LoaderModuleMockMixin
 from tests.support.mock import MagicMock, patch
 from tests.support.runtests import RUNTIME_VARS
@@ -44,7 +43,7 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
 
     # 'state' function tests: 1
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_state(self):
         """
         Test to invoke a state run on a given target
@@ -168,7 +167,10 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
 
         ret.update(
             {
-                "comment": "States ran successfully. No changes made to minion1, minion3, minion2."
+                "comment": (
+                    "States ran successfully. No changes made to minion1, minion3,"
+                    " minion2."
+                )
             }
         )
         del ret["__jid__"]
@@ -191,7 +193,7 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
 
     # 'function' function tests: 1
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_function(self):
         """
         Test to execute a single module function on a remote
@@ -204,7 +206,7 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
             "name": name,
             "changes": {},
             "result": None,
-            "comment": "Function state would be executed " "on target {}".format(tgt),
+            "comment": "Function state would be executed on target {}".format(tgt),
         }
 
         with patch.dict(saltmod.__opts__, {"test": True}):
@@ -213,9 +215,10 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
         ret.update(
             {
                 "result": True,
-                "changes": {"out": "highstate", "ret": {tgt: ""}},
-                "comment": "Function ran successfully."
-                " Function state ran on {}.".format(tgt),
+                "changes": {"ret": {tgt: ""}},
+                "comment": (
+                    "Function ran successfully. Function state ran on {}.".format(tgt)
+                ),
             }
         )
         with patch.dict(saltmod.__opts__, {"test": False}):
@@ -224,7 +227,7 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
             with patch.dict(saltmod.__salt__, {"saltutil.cmd": mock_cmd}):
                 self.assertDictEqual(saltmod.function(name, tgt), ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_function_when_no_minions_match(self):
         """
         Test to execute a single module function on a remote
@@ -278,11 +281,19 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
                     return {"tag": name, "data": {}}
                 return None
 
+            def __enter__(self):
+                return self
+
+            def __exit__(self, *args):
+                pass
+
         with patch.object(
             salt.utils.event, "get_event", MagicMock(return_value=Mockevent())
         ):
             with patch.dict(saltmod.__opts__, {"sock_dir": True, "transport": True}):
-                with patch.object(time, "time", MagicMock(return_value=1.0)):
+                with patch(
+                    "salt.states.saltmod.time.time", MagicMock(return_value=1.0)
+                ):
                     self.assertDictEqual(
                         saltmod.wait_for_event(name, "salt", timeout=-1.0), ret
                     )
@@ -338,10 +349,10 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
         with patch.dict(saltmod.__salt__, {"saltutil.wheel": wheel_mock}):
             self.assertDictEqual(saltmod.wheel(name), ret)
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_state_ssh(self):
         """
-        Test saltmod passes roster to saltutil.cmd
+        Test saltmod state passes roster to saltutil.cmd
         """
         origcmd = saltmod.__salt__["saltutil.cmd"]
         cmd_kwargs = {}
@@ -359,6 +370,27 @@ class SaltmodTestCase(TestCase, LoaderModuleMockMixin):
         assert "roster" in cmd_kwargs
         assert cmd_kwargs["roster"] == "my_roster"
 
+    @pytest.mark.slow_test
+    def test_function_ssh(self):
+        """
+        Test saltmod function passes roster to saltutil.cmd
+        """
+        origcmd = saltmod.__salt__["saltutil.cmd"]
+        cmd_kwargs = {}
+        cmd_args = []
+
+        def cmd_mock(*args, **kwargs):
+            cmd_args.extend(args)
+            cmd_kwargs.update(kwargs)
+            return origcmd(*args, **kwargs)
+
+        with patch.dict(saltmod.__opts__, {"test": False}), patch.dict(
+            saltmod.__salt__, {"saltutil.cmd": cmd_mock}
+        ):
+            saltmod.function("state", tgt="*", ssh=True, roster="my_roster")
+        assert "roster" in cmd_kwargs
+        assert cmd_kwargs["roster"] == "my_roster"
+
 
 class StatemodTests(TestCase, LoaderModuleMockMixin):
     def setup_loader_modules(self):
@@ -379,9 +411,9 @@ class StatemodTests(TestCase, LoaderModuleMockMixin):
         }
 
     def test_statemod_state(self):
-        """ Smoke test for for salt.states.statemod.state().  Ensures that we
-            don't take an exception if optional parameters are not specified in
-            __opts__ or __env__.
+        """Smoke test for for salt.states.statemod.state().  Ensures that we
+        don't take an exception if optional parameters are not specified in
+        __opts__ or __env__.
         """
         args = ("webserver_setup", "webserver2")
         kwargs = {
